@@ -36,7 +36,6 @@
 #include "phrasebook.h"
 
 #include <QDebug>
-#include <KConfigGroup>
 
 const int kTextColumn = 0;
 const int kShortcutColumn = 1;
@@ -570,7 +569,7 @@ QModelIndex PhraseBookDialog::getCurrentParent()
     return currentIndex;
 }
 
-void PhraseBookDialog::focusNewItem(QModelIndex parent, QStandardItem *item)
+void PhraseBookDialog::focusNewItem(const QModelIndex &parent, QStandardItem *item)
 {
     m_ui->treeView->expand(parent);
     QModelIndex newIndex = m_bookModel->indexFromItem(item);
